@@ -20,7 +20,7 @@ use File::ShareDir::ProjectDistDir;
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = 'v1.0.0';
+our $VERSION = 'v1.1.1';
 
 # permit callers to sloppily pass undefined hash values
 sub BUILDARGS
@@ -171,8 +171,8 @@ sub run
 		: '';
 	my @pkg = try { @{ $params{pkg} } }
 	catch {
-		$self->_logger->error('No packages resolved');
-		die;
+		$self->_logger->warning('No packages resolved');
+		return ();
 	};
 	my @pkgauto = try { @{ $params{'pkg-auto'} } }
 	catch {
@@ -208,6 +208,7 @@ sub run
 	);
 
 	my %vars = (
+		node        => $self->node,
 		suite       => $self->suite,
 		pkgdesc     => $pkgdesc,
 		pkglist     => $pkglist,
@@ -227,6 +228,9 @@ sub run
 	$altvars{tweaklist} =~ s,chroot\s+/target\s+,,g;
 	$altvars{tweaklist} =~ s,/target/,/,g;
 
+	# TODO: maybe move below (or only $''{ part?) to reclass parser
+	$altvars{tweaklist} =~ s/\\\K''(?=n)|\$\K''(?=\{)//g;
+
 	my $altcontent = '';
 	$template->process( \$self->altinfile->slurp, \%altvars, \$altcontent );
 	$self->altoutfile->spew( $altcontent . "\n" );
