@@ -4,7 +4,8 @@ use 5.010;
 use strictures 1;
 use utf8;
 
-use Type::Library -base, -declare => qw( DataDir ClassDir NodeDir SkelDir Suite );
+use Type::Library -base,
+	-declare => qw( DataDir ClassDir NodeDir SkelDir Suite );
 use Type::Utils -all;
 use Types::Path::Tiny qw(Dir);
 use Types::Common::String qw(LowerCaseSimpleStr);
@@ -12,7 +13,7 @@ use Types::Common::String qw(LowerCaseSimpleStr);
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = 'v1.0.0';
+our $VERSION = 'v1.1.1';
 
 declare DataDir, as Dir, coercion => 1, message {
 	'Must be an existing directory containing directories for boxer classes and/or boxer nodes';
